package de.fhw.swtvertiefung.knauf.jsp4.tags;

import java.io.IOException;
import java.util.Iterator;

import javax.servlet.jsp.tagext.*;
import javax.servlet.jsp.JspException;

import de.fhw.swtvertiefung.knauf.jsp4.Historie;
import de.fhw.swtvertiefung.knauf.jsp4.Seitenlaengen;

/**Tag-Klasse fr ein Tag "Laufe ber ein bestimmtes SessionContext-Attribut
 * vom Typ 'Historie' und stelle den aktuellen Wert 
 * in einem Attribut des PageContext bereit".
 * 
 * @author Wolfgang Knauf
 *
 */
public class LoopOverHistorieTag extends BodyTagSupport
{
  /**Das SessionContext-Attribut, in dem die Historie steckt.
   * Pflicht-Attribut */
  private String strSessionContextAttribute = "";

  /**Name eines PageContext-Attributs, in das das aktuelle Item gepackt werden soll.
   * Pflicht-Attribut */
  private String strCurrentItem = "";

  /**Der Iterator ber die Historie. Wird im "doStartTag" initialisiert. */
  private Iterator iteratorHistorie = null;

  /**Tag ausfhren.
   * 
   * Es wird geprft ob ein bestimmtes Session-Context-Attribut
   * existiert und vom Typ "Historie" ist.
   * Wenn ja wird der Iterator initialisiert und das erste "Seitenlaengen"-Item
   * in ein PageContext-Attribut geschrieben.
   * 
   * @throws JspException
   * @throws IOException
   */
  public int doStartTag() throws JspException
  {
    System.out.println("LoopOverHistorieTag.doStartTag: SessionContextAttribute=" + this.strSessionContextAttribute
        + ", Item=" + this.strCurrentItem);

    Object objSessionContextAttribute = this.pageContext.getSession().getAttribute(this.strSessionContextAttribute);
    if (objSessionContextAttribute != null)
    {
      System.out.println("LoopOverHistorieTag.doStartTag: SessionContext-Attribut existiert !");
      //Historie holen:
      //Vor dem Typecast erstmal eine Typprfung:
      if (!(objSessionContextAttribute instanceof Historie))
        throw new JspException("Attribut " + this.strSessionContextAttribute
            + " ist nicht vom Typ 'Historie' sondern '" + objSessionContextAttribute.getClass().toString());
      Historie historie = (Historie) objSessionContextAttribute;
      //Iterator initialisieren:
      this.iteratorHistorie = historie.getIterator();
      //Ist berhaupt ein Item vorhanden ?
      if (this.iteratorHistorie.hasNext() == true)
      {
        System.out.println("LoopOverHistorieTag.doStartTag: mind. ein Historie-Item gefunden");
        //Aktuelles Item holen
        Seitenlaengen seitenlaengeAktuell = (Seitenlaengen) this.iteratorHistorie.next();
        //Ab damit in den PageContext:
        this.pageContext.setAttribute(this.strCurrentItem, seitenlaengeAktuell);
        return TagSupport.EVAL_BODY_INCLUDE;
      }
      else
      {
        //Kein Item im Iterator:
        System.out.println("LoopOverHistorieTag.doStartTag: Historie ist leer ");
        return TagSupport.SKIP_BODY;
      }
    }
    else
    {
      System.out.println("LoopOverHistorieTag.doStartTag: Request-Attribut existiert nicht");
      return TagSupport.SKIP_BODY;
    }
  }

  /**Body-Content des aktuellen Tags auswerten. Hier greift die Iterator-Logik: wenn wir noch nicht durch die gesamte
   * Historie gelaufen sind dann holen wir das nchste Iterator-Item und werten das Tag erneut aus.
   */
  public int doAfterBody() throws JspException
  {
    System.out.println("LoopOverHistorieTag.doAfterBody");

    if (this.iteratorHistorie.hasNext() == true)
    {
      System.out.println("LoopOverHistorieTag.doAfterBody: weiteres Historie-Item gefunden");
      //Aktuelles Item holen
      Seitenlaengen seitenlaengeAktuell = (Seitenlaengen) this.iteratorHistorie.next();
      //Ab damit in den PageContext:
      this.pageContext.setAttribute(this.strCurrentItem, seitenlaengeAktuell);
      //Und nochmal durch das Tag laufen !
      return TagSupport.EVAL_BODY_AGAIN;
    }
    else
    {
      //Kein Item im Iterator:
      System.out.println("LoopOverHistorieTag.doAfterBody: Kein weiteres Historie-Item gefunden.");
      return TagSupport.SKIP_BODY;
    }
  }

  /**Release: Aufrumen.
   * Hier muss nichts weiter passieren.
   * 
   */
  public void release()
  {
    System.out.println("LoopOverHistorieTag.release: " + this.strSessionContextAttribute);

    if (this.pageContext.getAttribute("item") != null)
      System.out.println("LoopOverHistorieTag.release: remove Attribute 'item'");
    else
      System.out.println("LoopOverHistorieTag.release: kein Attribute 'item' vorhanden");
    this.pageContext.removeAttribute("item");

    super.release();

  }

  /**Attribut "sessionContextAttribute" setzen (Pflichtfeld).
   * @param str_SessionContextAttribute
   */
  public void setSessionContextAttribute(String str_SessionContextAttribute)
  {
    System.out.println("LoopOverHistorieTag.setSessionContextAttribute: " + str_SessionContextAttribute);
    this.strSessionContextAttribute = str_SessionContextAttribute;
  }

  /**Attribut "item" setzen (Pflichtfeld).
   * Das ist der Name eines PageContext-Attributs in den das aktuelle Item gepackt wird.
   * @param str_Item
   */
  public void setItem(String str_Item)
  {
    System.out.println("LoopOverHistorieTag.setItem: " + str_Item);
    this.strCurrentItem = str_Item;
  }
}
