package de.fhw.swtvertiefung.knauf.jsp4.tags;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.SimpleTagSupport;

import de.fhw.swtvertiefung.knauf.jsp4.Seitenlaengen;

/**Tag-Klasse fr ein Tag "gib einen der Werte a, b oder c
 * fr ein Seitenlaenge-Item aus".
 * 
 * @author Wolfgang Knauf
 *
 */
public class PrintPageContextSeitenlaengeTag extends SimpleTagSupport
{
  /**Der PageContextAttribut in dem die Historie steckt.
   * Pflicht-Attribut */
  private String strPageContextAttribute = "";
  
  /**Das Feld von "Seitenlaenge" das ausgegeben werden soll.
   * Werte sind 'a', 'b' und 'c'.
   * Pflicht-Attribut */
  private String strSeitenlaengeValue = "";

  /**Tag ausfhren.
   * Es wird im PageContext ein konfigurierbares Attribut vom Typ "Seitenlaengen" gesucht
   * und einer der Werte a, b oder c ausgegeben. 
   * @exception JspException Bei Fehlern.
   */
  public void doTag() throws JspException
  {
    System.out.println("PrintPageContextSeitenlaengeTag.doTag: " + this.strPageContextAttribute);

    //Request-Attribut auswerten:
    Object objValue = this.getJspContext().getAttribute(this.strPageContextAttribute, PageContext.PAGE_SCOPE);
    //Wenn er nicht NULL ist und vom Typ "Historie" dann ausgeben:
    if (objValue != null)
    {
      //TypCheck:
      if (!(objValue instanceof Seitenlaengen) )
        throw new JspException ("PageContextAttribut " + this.strPageContextAttribute + " ist vom Typ " + objValue.getClass().toString()); 
      try
      {
        Seitenlaengen seitenlaenge = (Seitenlaengen) objValue;
        String strValue = "";
        if ("a".equals(this.strSeitenlaengeValue) == true)
          strValue = Double.toString(seitenlaenge.getA());
        else if ("b".equals(this.strSeitenlaengeValue) == true)
          strValue = Double.toString(seitenlaenge.getB());
        else if ("c".equals(this.strSeitenlaengeValue) == true)
          strValue = Double.toString(seitenlaenge.getC());
        else
          throw new IllegalArgumentException ("seitenlaengeValue erlaubt nur die Werte 'a', 'b' und 'c', nicht '" + this.strSeitenlaengeValue + "'");
        
        System.out.println ("PrintPageContextSeitenlaengeTag.doTag: Ausgabe von '" + strValue + "'" );
        this.getJspContext().getOut().write(strValue);
      }
      catch (IOException ioex)
      {
        throw new JspException ("IOException: " + ioex.getMessage(), ioex);
      }
    }
    else
    {
      System.out.println ("PrintPageContextSeitenlaengeTag.doTag: kein PageContext-Attribut " + this.strPageContextAttribute + " gefunden !" );
      
    }
  }

  /**Attribut "pageContextAttribute" setzen (Pflichtfeld).
   * @param str_PageContextAttribute
   */
  public void setPageContextAttribute(String str_PageContextAttribute)
  {
    System.out.println("PrintPageContextSeitenlaengeTag.setPageContextAttribute: " + str_PageContextAttribute);
    this.strPageContextAttribute = str_PageContextAttribute;
  }
  
  /**Attribut "seitenlaengeValue" setzen (Pflichtfeld).
   * Erlaubt sind nur die Werte "a", "b" und "c" !
   * @param str_SeitenlaengeValue
   */
  public void setSeitenlaengeValue(String str_SeitenlaengeValue)
  {
    System.out.println("PrintPageContextSeitenlaengeTag.setSeitenlaengeValue: " + str_SeitenlaengeValue);
    if ("a".equals(str_SeitenlaengeValue) == false && "b".equals(str_SeitenlaengeValue) == false &&
        "c".equals(str_SeitenlaengeValue) == false)
      throw new IllegalArgumentException ("seitenlaengeValue erlaubt nur die Werte 'a', 'b' und 'c', nicht '" + str_SeitenlaengeValue + "'");
    
    this.strSeitenlaengeValue = str_SeitenlaengeValue;
  }
}
